[jboss-svn-commits] JBoss Common SVN: r3350 - jboss-logmanager/trunk/src/main/java/org/jboss/logmanager.

jboss-svn-commits at lists.jboss.org jboss-svn-commits at lists.jboss.org
Wed Jul 8 23:35:32 EDT 2009


Author: david.lloyd at jboss.com
Date: 2009-07-08 23:35:31 -0400 (Wed, 08 Jul 2009)
New Revision: 3350

Modified:
   jboss-logmanager/trunk/src/main/java/org/jboss/logmanager/ExtHandler.java
Log:
Make case consistent with other usages

Modified: jboss-logmanager/trunk/src/main/java/org/jboss/logmanager/ExtHandler.java
===================================================================
--- jboss-logmanager/trunk/src/main/java/org/jboss/logmanager/ExtHandler.java	2009-07-09 03:05:13 UTC (rev 3349)
+++ jboss-logmanager/trunk/src/main/java/org/jboss/logmanager/ExtHandler.java	2009-07-09 03:35:31 UTC (rev 3350)
@@ -38,7 +38,7 @@
 
     private static final String LOGGER_CLASS_NAME = org.jboss.logmanager.Logger.class.getName();
     private static final Permission CONTROL_PERMISSION = new LoggingPermission("control", null);
-    private volatile boolean autoflush;
+    private volatile boolean autoFlush;
 
     /**
      * The sub-handlers for this handler.  May only be updated using the {@link #handlersUpdater} atomic updater.  The array
@@ -55,7 +55,7 @@
     /** {@inheritDoc} */
     public final void publish(final LogRecord record) {
         publish((record instanceof ExtLogRecord) ? (ExtLogRecord) record : new ExtLogRecord(record, LOGGER_CLASS_NAME));
-        if (autoflush) flush();
+        if (autoFlush) flush();
     }
 
     /**
@@ -143,19 +143,19 @@
      *
      * @return {@code true} if auto-flush is enabled
      */
-    public boolean isAutoflush() {
-        return autoflush;
+    public boolean isAutoFlush() {
+        return autoFlush;
     }
 
     /**
      * Change the autoflush setting for this handler.
      *
      * @param autoflush {@code true} to automatically flush after each write; false otherwise
      * @throws SecurityException if a security manager exists and if the caller does not have {@code LoggingPermission(control)}
      */
-    public void setAutoflush(final boolean autoflush) throws SecurityException {
+    public void setAutoFlush(final boolean autoFlush) throws SecurityException {
         checkAccess();
-        this.autoflush = autoflush;
+        this.autoFlush = autoFlush;
     }
 
     /**
@@ -143,19 +143,19 @@
      * Change the autoflush setting for this handler.
      *
-     * @param autoflush {@code true} to automatically flush after each write; false otherwise
+     * @param autoFlush {@code true} to automatically flush after each write; false otherwise
      * @throws SecurityException if a security manager exists and if the caller does not have {@code LoggingPermission(control)}
      */




More information about the jboss-svn-commits mailing list